@@ -28,9 +28,9 @@ if spec is not None:
 
 
 class ModelParser:
-    def __init__(self, should_transform_inputs=False,
+    def __init__(self, should_transform_inputs_and_outputs=False,
                  custom_layers: Optional[Dict[str, Type[tf.keras.layers.Layer]]] = None):
-        self._should_transform_inputs = should_transform_inputs
+        self._should_transform_inputs_and_outputs = should_transform_inputs_and_outputs
 
         self.custom_layers = custom_layers
         if custom_layers is None:
@@ -107,7 +107,6 @@ class ModelParser:
         input_names = [_input.name for _input in onnx_model.graph.input]
         k_model = onnx_to_keras(onnx_model, input_names=input_names,
                                 name_policy='attach_weights_name')
-
         return self.convert_to_keras_model(k_model)
 
     def _load_keras_model_with_custom_layers(self, file_path: str):
@@ -121,11 +120,9 @@ class ModelParser:
         return self.convert_to_keras_model(imported_model)
 
     def convert_to_keras_model(self, k_model) -> Tuple[Dict[str, NodeResponse], Model]:
-        inputs_to_transpose = []
-        if self._should_transform_inputs:
-            inputs_to_transpose = [k_input.name for k_input in k_model.inputs]
+        converted_k_model = convert_channels_first_to_last(
+            k_model, self._should_transform_inputs_and_outputs, self.custom_layers)
 
-        converted_k_model = convert_channels_first_to_last(k_model, inputs_to_transpose, self.custom_layers)
         model_schema = json.loads(converted_k_model.to_json())
         model_schema = replace_dots_in_model_schema(model_schema)
 
